==> haskell-sourcemap-0.1.6-72-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-7SbuigQzoa553sMgb5y1g1
key: sourcemap-0.1.6-7SbuigQzoa553sMgb5y1g1
license: BSD-3-Clause
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
abi: e8205e6edbbb0ffe7160d1dd1b1574c3
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
import-dirs: /usr/lib/ghc-8.4.3/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/sourcemap-0.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-7SbuigQzoa553sMgb5y1g1
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    aeson-1.3.1.1-9XRC4e94J4n99AnBXEVUy1
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH process-1.6.3.0
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8 text-1.2.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             aeson-1.3.1.1-9XRC4e94J4n99AnBXEVUy1=35b49024653eeb9b79eed81b6925c2b9
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH=8e6e77bd73af6a8072fdc40742d8861e
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sourcemap-0.1.6-73-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-5fCFdly1DQ07VkbQYTE5At
key: sourcemap-0.1.6-5fCFdly1DQ07VkbQYTE5At
license: BSD-3-Clause
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
abi: 5c2b583d7da3d43c10308e23b819a2f3
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
import-dirs: /usr/lib/ghc-8.4.3/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/sourcemap-0.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-5fCFdly1DQ07VkbQYTE5At
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    aeson-1.3.1.1-J1bdggn8TZj5jjcHYxM7mi
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH process-1.6.3.0
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8 text-1.2.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             aeson-1.3.1.1-J1bdggn8TZj5jjcHYxM7mi=4bd33a472ed49d1f25a046c18b4acb2d
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH=8e6e77bd73af6a8072fdc40742d8861e
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
